# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import enum

import winrt.system
from winui3._winui3_microsoft_ui_windowing import (
    AppWindow,
    AppWindowChangedEventArgs,
    AppWindowClosingEventArgs,
    AppWindowPresenter,
    AppWindowTitleBar,
    CompactOverlayPresenter,
    DisplayArea,
    DisplayAreaWatcher,
    FullScreenPresenter,
    OverlappedPresenter,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winui3._winui3_microsoft_ui_windowing import (
        AppWindowPresenter_Static,
    )

__all__ = [
    "AppWindowPresenterKind",
    "CompactOverlaySize",
    "DisplayAreaFallback",
    "DisplayAreaWatcherStatus",
    "IconShowOptions",
    "OverlappedPresenterState",
    "TitleBarHeightOption",
    "TitleBarTheme",
    "AppWindow",
    "AppWindowChangedEventArgs",
    "AppWindowClosingEventArgs",
    "AppWindowPresenter",
    "AppWindowTitleBar",
    "CompactOverlayPresenter",
    "DisplayArea",
    "DisplayAreaWatcher",
    "FullScreenPresenter",
    "OverlappedPresenter",
]

class AppWindowPresenterKind(enum.IntEnum):
    DEFAULT = 0
    COMPACT_OVERLAY = 1
    FULL_SCREEN = 2
    OVERLAPPED = 3

class CompactOverlaySize(enum.IntEnum):
    SMALL = 0
    MEDIUM = 1
    LARGE = 2

class DisplayAreaFallback(enum.IntEnum):
    NONE = 0
    PRIMARY = 1
    NEAREST = 2

class DisplayAreaWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class IconShowOptions(enum.IntEnum):
    SHOW_ICON_AND_SYSTEM_MENU = 0
    HIDE_ICON_AND_SYSTEM_MENU = 1

class OverlappedPresenterState(enum.IntEnum):
    MAXIMIZED = 0
    MINIMIZED = 1
    RESTORED = 2

class TitleBarHeightOption(enum.IntEnum):
    STANDARD = 0
    TALL = 1
    COLLAPSED = 2

class TitleBarTheme(enum.IntEnum):
    LEGACY = 0
    USE_DEFAULT_APP_MODE = 1
    LIGHT = 2
    DARK = 3

